pub enum BackupStrategy {
HardLinkOrCopy,
Copy,
}Expand description
Strategy used to retain the last-confirmed executable for rollback.
Variants
HardLinkOrCopy
Prefer a hard link and copy bytes when the filesystem rejects links.
Copy
Always copy bytes and preserve the executable permission mode.