reexec

Function reexec 

pub fn reexec(
    executable: &Path,
    args: impl IntoIterator<Item = OsString>,
) -> Result<Infallible>
Replaces the current Unix process with the installed executable.

Adopters supervised by systemd or another process manager may instead exit with an agreed restart status after receiving either InstallOutcome variant.