pub fn restart_command(
executable: &Path,
args: impl IntoIterator<Item = OsString>,
) -> CommandExpand description
Builds a restart command without consulting global process arguments.
pub fn restart_command(
executable: &Path,
args: impl IntoIterator<Item = OsString>,
) -> CommandBuilds a restart command without consulting global process arguments.